<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

use URL;
use DB;

class Category extends Model
{
    protected $primaryKey = 'id';
    protected $table = 'categories';

    /**
     * The attributes that are mass assignable.
     *	
     * @var array
     */
    protected $fillable = [
        'parent_id', 'cat_order', 'name', 'description', 'slug', 'cat_image', 'active', 'meta_description', 'meta_keywords'
    ];

    public static function categoryAll()
    {

        $category = DB::table('categories as cat')
                            ->leftJoin('categories as pcat','cat.parent_id','pcat.id')
                            ->select(
                               'cat.id as id',
                               'cat.parent_id as parent_id',
                               'pcat.name as pcat_name',
                               'pcat.slug as pcat_slug',
                               'cat.cat_order as cat_order',
                               'cat.name as name',
                               'cat.description as description',
                               'cat.slug as slug',
                               'cat.cat_image as cat_image',
                               'cat.active as active',
                               'cat.meta_description as meta_description',
                               'cat.meta_keywords as meta_keywords'
                            )
                            ->orderBy('id','DESC')
                            ->paginate(10);
       
        return $category;
    }


    public static function categoryByID($id)
    {

        $category = DB::table('categories as cat')
                            ->leftJoin('categories as pcat','cat.parent_id','pcat.id')
                            ->where('cat.id',$id)
                            ->select(
                               'cat.id as id',
                               'cat.parent_id as parent_id',
                               'pcat.name as pcat_name',
                               'pcat.slug as pcat_slug',
                               'cat.cat_order as cat_order',
                               'cat.name as name',
                               'cat.description as description',
                               'cat.slug as slug',
                               'cat.cat_image as cat_image',
                               'cat.active as active',
                               'cat.meta_description as meta_description',
                               'cat.meta_keywords as meta_keywords'
                            )
                            ->first();
       
        return $category;
    }

    public static function categories_SEL()
    {

        $allCAT_SEL = Category::with('childrenCategories')
                                // ->where('active',1)
                                ->get();
       
        return $allCAT_SEL;
    }

    // kreiram listu kategorija i podkategorija -------------------------------------------- //
    public function categories()
    {
        return $this->hasMany(Category::class,'parent_id');
    }

    public function childrenCategories()
    {
        return $this->hasMany(Category::class,'parent_id')->with('categories');
    }
    // kreiram listu kategorija i podkategorija -------------------------------------------- //

    public static function categorySLUG_By_catID($catID)
    {

        $categoryW_Parents = Category::where('id',$catID)->first();

        // pakujem sve parent kategorije u niz $allCATdata
        $allCATdata = array();

        // dodajem AKTIVNU kategoriju u niz
        array_push($allCATdata, $categoryW_Parents->slug);

        // dodajem sve parent kategorije u niz
        foreach ($categoryW_Parents->getParentsAttribute() as $pCAT):
            if (!in_array($pCAT['slug'], $allCATdata)):
                array_push($allCATdata, $pCAT['slug']);
            endif;
        endforeach;

        $siteURL = URL::to('/');
        array_push($allCATdata, $siteURL);

        $final = array_reverse($allCATdata);

        $url = '';
        foreach ($final as $key => $value) {
            if ($key == 0):
                $url .= $value;
            else:
                $url .= '/'.$value;
            endif;
        }

        return $url;
    }

    // Reverse CAT ----------------------------------------------------------------//
    public function parentReverse()
    {
        return $this->belongsTo('App\Category', 'parent_id');
    }

    public function childrenReverse()
    {
        return $this->hasMany('App\Category', 'parent_id');
    }


    public function getParentsAttribute()
    {
        $parents = collect([]);

        $parent = $this->parentReverse;

        while(!is_null($parent)) {
            $parents->push($parent);
            $parent = $parent->parentReverse;
        }

        return $parents;
    }
    // Reverse CAT ----------------------------------------------------------------//

    
    // relatioships
    public function posts()
    {
        return $this->hasMany('App\Post','category_id','id');
    }
    public function modules()
    {
        return $this->hasMany('App\Module','category_id','id');
    }
}