<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use DB;
use Auth;
use Log;
use Carbon\Carbon;

use App\User;
use App\Submission;
use App\SMSRequests;

class WService_UserRegistrationController extends Controller
{
    /**
     * API User registration
     *
     * @return \Illuminate\Http\Response
     */
    public function userRegistration(Request $request)
    {

        // Check if SMS is ENABLED
        if (setting('sms.enable_sms') == 1):

            $sada = Carbon::now();

            Log::info('SMSRequest_IN...'.json_encode($request->all()).'|'.$sada);

            // if POST is complete
            $validator = \Validator::make($request->all(), [
                'phone' => 'required',
                'msgid' => 'required',
                'msg' => 'required',
            ]);

            if ($validator->fails()) {
                return response()->json(['errors'=>$validator->errors()],422);
            }

            

            $phone = $request->input('phone');
            $msgid = $request->input('msgid');
            $msg = $request->input('msg');

            // get last 6 and 7 char from phone to check if there is user regiter with that number
            $phone_last6 = substr($phone, -6);
            $phone_last7 = substr($phone, -7);

            // first check with last 6
            $chk_user = DB::table('users as u')
                                ->whereRaw('LOWER(u.phone) LIKE ? ',trim('%'.strtolower($phone_last6)).'%')
                                ->get();

            // if there is more then one result, make new search
            if (count($chk_user) > 1):

                // second check with last 7
                $chk_user = DB::table('users as u')
                                    ->whereRaw('LOWER(u.phone) LIKE ? ',trim('%'.strtolower($phone_last7)).'%')
                                    ->get();

            endif;

            // split MSG and create USER and SUBMISSION data
            $msg_arr = explode(' ',$msg);
            // clear empty values form MSG array
            $msg_arr_clean = array_filter($msg_arr, fn($value) => !is_null($value) && $value !== '');

            if (
                $msg_arr_clean
                && count($msg_arr_clean) > 1
            ):

                // BI
                $bi = $msg_arr_clean[0];

                // check if submission with KOD exist
                $checkBI = Submission::where('bi',$bi)->first();

                if (!$checkBI):

                    // user NAME
                    if (!array_key_exists('1',$msg_arr_clean)):
                        $sve['success'] = false;
                        $sve['message'] = 'Neuspešna prijava. Molimo Vas da proverite da li ste pravilno uneli podatke, kod sa isečka(razmak)ime(razmak)prezime. Vas Unilever';
                        $httpResponse = 200;
                    else:
                        $name = $msg_arr_clean[1];
                    endif;

                    // user LAST_NAME
                    $last_name = null;
                    if (array_key_exists('2',$msg_arr_clean)):
                        $last_name = $msg_arr_clean[2];
                    endif;

                    // user CITY
                    $city = null;
                    if (array_key_exists('3',$msg_arr_clean)):
                        $city = $msg_arr_clean[3];
                    endif;

                    if (count($chk_user) == 0):

                        // REGISTER new user
                        $NEWuser = User::create([
                            'name' => $name,
                            'last_name' => $last_name,
                            'phone' => $phone,
                            'email' => null,
                            'address' => null,
                            'city' => $city,
                            'password' => null,
                        ]);
                
                        $NEWuser->assignRole(5);

                        $user_id = $NEWuser->id;

                    else:

                        $user_id = $chk_user[0]->id;

                    endif;


                    // CREATE NEW submission **************************************************************************** /
                    
                    // submission SOURCE
                    $source = 'sms';

                    // submission STATUS
                    $status = 0;

                    $NEWSubmission = Submission::addNewSubmission($user_id,$bi,$source,$status);

                    // CREATE NEW submission **************************************************************************** /


                    // log SMS REQUESTS ******************************************************************************** /

                    $NEWSMSRequest = SMSRequests::addNewRequest($phone,$msgid,$msg,$NEWSubmission->id,$user_id);

                    // log SMS REQUESTS ******************************************************************************** /

                    // Console LOG for Request
                    Log::info('SMSRequest...'.json_encode($request->all()).'|'.$sada.'|user_id:'.$user_id.'|submission_id:'.$NEWSubmission->id);


                    $sve['success'] = true;
                    $sve['message'] = setting('sms.rsp_received_message');
                    $httpResponse = 200;

                    return response()->json($sve,$httpResponse);

                else:

                    $sve['success'] = false;
                    $sve['message'] = setting('sms.rsp_bi_number_in_use');
                    $httpResponse = 200;

                    return response()->json($sve,$httpResponse);

                endif;

            else:

                // No MSG content!!!!
                $sve['success'] = false;
                $sve['message'] = 'Neuspešna prijava. Molimo Vas da proverite da li ste pravilno uneli podatke, kod sa isečka(razmak)ime(razmak)prezime. Vas Unilever';
                $httpResponse = 200;
        
                return response()->json($sve,$httpResponse);

            endif;

        else:

            // SMS is NOT ENABLED
            $sve = array();
            $httpResponse = 401;

            return response()->json($sve,$httpResponse);

        endif;
    }
}
